'use strict';
var self = BatchStepletConsoleAdapter;
module.exports = self;
var async = require('async');
var _ = require('underscore');
var uuid = require('node-uuid');
var ApiAdapter = require('./Adapter.js');
function BatchStepletConsoleAdapter(jFrogPipelinesSessionId, apiToken, stepletIds, pipelineId, jobConsoleBatchSize, jobConsoleBufferTimeInterval) {
    this.who = util.format('%s|helpers|pipelines|BatchStepletConsoleAdapter|stepletId:%s|' +
        'jFrogPipelinesSessionId:%s', global.who, stepletIds);
    this.stepletIds = stepletIds || [];
    this.pipelineId = pipelineId;
    this.startTimeInMicroSec = new Date().getTime() * 1000;
    var processStartTime = process.hrtime();
    this.processStartTimeInMicroSec =
        processStartTime[0] * 1e6 + processStartTime[1] / 1e3;
    this.ApiAdapter = new ApiAdapter(jFrogPipelinesSessionId, apiToken);
    this.batchSize = jobConsoleBatchSize;
    this.buffer = [];
    this.bufferTimeInterval = jobConsoleBufferTimeInterval || 3000;
    this.bufferTimer = null;
    this.pendingApiCalls = 0;
    this.currentTime = 0;
    this.lineNumber = 0;
    this.consoleGrpIdByStepletId = {};
    this.consoleGrpNameByStepletId = {};
    this.consoleCmdNameByStepletId = {};
    this.consoleCmdIdByStepletId = {};
}
BatchStepletConsoleAdapter.prototype.openGrp = function (consoleGrpName) {
    var that = this;
    _.each(that.stepletIds, function (stepletId) {
        that.consoleGrpNameByStepletId[stepletId] = consoleGrpName;
        that.consoleGrpIdByStepletId[stepletId] = uuid.v4();
        var _consoleGrpId = that.consoleGrpIdByStepletId[stepletId];
        var _consoleGrpName = that.consoleGrpNameByStepletId[stepletId];
        var consoleGrp = {
            stepletId: stepletId,
            consoleId: _consoleGrpId,
            parentConsoleId: 'root',
            type: 'grp',
            message: _consoleGrpName,
            timestamp: that._getTimestamp(),
            isShown: true
        };
        that.buffer.push(consoleGrp);
    });
    that._postToStepletConsole(true);
};
BatchStepletConsoleAdapter.prototype.closeGrp = function (isSuccess) {
    var that = this;
    _.each(that.stepletIds, function (stepletId) {
        if (!that.consoleGrpNameByStepletId[stepletId])
            return;
        if (!_.isBoolean(isSuccess))
            isSuccess = true;
        that.closeCmd();
        var consoleGrp = {
            stepletId: stepletId,
            consoleId: that.consoleGrpIdByStepletId[stepletId],
            parentConsoleId: 'root',
            type: 'grp',
            message: that.consoleGrpNameByStepletId[stepletId],
            timestamp: that._getTimestamp(),
            timestampEndedAt: that._getTimestamp(),
            isSuccess: isSuccess,
            isShown: true
        };
        that.buffer.push(consoleGrp);
        that.consoleGrpNameByStepletId[stepletId] = null;
        that.consoleGrpIdByStepletId[stepletId] = null;
    });
    that._postToStepletConsole(true);
};
BatchStepletConsoleAdapter.prototype.openCmd = function (consoleCmdName) {
    var that = this;
    _.each(that.stepletIds, function (stepletId) {
        that.consoleCmdNameByStepletId[stepletId] = consoleCmdName;
        that.consoleCmdIdByStepletId[stepletId] = uuid.v4();
        var consoleGrp = {
            stepletId: stepletId,
            consoleId: that.consoleCmdIdByStepletId[stepletId],
            parentConsoleId: that.consoleGrpIdByStepletId[stepletId],
            type: 'cmd',
            message: that.consoleCmdNameByStepletId[stepletId],
            timestamp: that._getTimestamp(),
            isShown: true
        };
        that.buffer.push(consoleGrp);
    });
    that._postToStepletConsole(true);
};
BatchStepletConsoleAdapter.prototype.closeCmd = function (isSuccess) {
    var that = this;
    _.each(that.stepletIds, function (stepletId) {
        if (!that.consoleCmdNameByStepletId[stepletId])
            return;
        if (!_.isBoolean(isSuccess))
            isSuccess = true;
        var consoleGrp = {
            stepletId: stepletId,
            consoleId: that.consoleCmdIdByStepletId[stepletId],
            parentConsoleId: that.consoleGrpIdByStepletId[stepletId],
            type: 'cmd',
            message: that.consoleCmdNameByStepletId[stepletId],
            timestamp: that._getTimestamp(),
            timestampEndedAt: that._getTimestamp(),
            isSuccess: isSuccess,
            isShown: false
        };
        that.buffer.push(consoleGrp);
        that.consoleCmdNameByStepletId[stepletId] = null;
        that.consoleCmdIdByStepletId[stepletId] = null;
    });
    that._postToStepletConsole(true);
};
BatchStepletConsoleAdapter.prototype.publishMsg = function (message) {
    var that = this;
    _.each(that.stepletIds, function (stepletId) {
        var consoleGrp = {
            stepletId: stepletId,
            consoleId: uuid.v4(),
            parentConsoleId: that.consoleCmdIdByStepletId[stepletId],
            type: 'msg',
            message: message,
            timestamp: that._getTimestamp(),
            isShown: true
        };
        that.buffer.push(consoleGrp);
    });
    that._postToStepletConsole(false);
};
BatchStepletConsoleAdapter.prototype._postToStepletConsole = function (forced) {
    var that = this;
    var who = that.who + '|_postToStepletConsole';
    if (that.buffer.length > that.batchSize || forced) {
        if (that.bufferTimer) {
            clearTimeout(that.bufferTimer);
            that.bufferTimer = null;
        }
        var consoles = that.buffer.splice(0, that.buffer.length);
        if (consoles.length === 0)
            return;
        var consolesByStepletId = _.groupBy(consoles, 'stepletId');
        async.eachOfLimit(consolesByStepletId, 5, function (consoles, stepletId, next) {
            var body = {
                stepletId: parseInt(stepletId),
                pipelineId: that.pipelineId,
                stepletConsoles: consoles
            };
            that.pendingApiCalls++;
            that.ApiAdapter.postStepletConsoles(body, function (err) {
                that.pendingApiCalls--;
                if (err) {
                    logger.error(who, 'postStepletConsoles Failed', err);
                    return next(err);
                }
                logger.trace(who, 'Succeeded');
                logger.debug(`Posted steplet ${stepletId} logs`, body);
                return next();
            });
        });
    }
    else if (!that.bufferTimer) {
        that.bufferTimer = setTimeout(function () {
            this._postToStepletConsole(true);
        }.bind(that), that.bufferTimeInterval);
    }
};
BatchStepletConsoleAdapter.prototype.getPendingApiCallCount = function () {
    var that = this;
    return that.pendingApiCalls;
};
BatchStepletConsoleAdapter.prototype.flushConsoles = function (callback) {
    let that = this;
    const who = that.who + '|' + that.flushConsoles.name;
    logger.debug(who, 'Inside');
    const asyncRetryOpts = {
        times: 4,
        interval: 1000
    };
    async.retry(asyncRetryOpts, function (callback) {
        if (that.getPendingApiCallCount() < 1)
            return callback();
        return callback(true);
    }, function (err) {
        if (err) {
            logger.error(`${who}, 
          Still posting steplet consoles`);
        }
        return callback();
    });
};
BatchStepletConsoleAdapter.prototype._getTimestamp = function () {
    var that = this;
    var currentProcessTime = process.hrtime();
    return Math.round(that.startTimeInMicroSec +
        (currentProcessTime[0] * 1e6 + currentProcessTime[1] / 1e3) -
        that.processStartTimeInMicroSec);
};
//# sourceMappingURL=BatchStepletConsoleAdapter.js.map