'use strict';
var self = Lock;
module.exports = self;
var ApiAdapter = require('./Adapter.js');
var { applicationContext, SYSTEM_SERVICE_INSTANCE_INITIALIZER } = require('@jfrog-pipelines/microservice');
function Lock(params) {
    this.id = null;
    this.name = params.name;
    this.timeoutInMs = params.lockTimeoutInMs;
    this.timerIntervalInMs = params.lockTimerInMs;
    this.timeoutAt = null;
    this.isValid = false;
    this.timeout = null;
    this.who = '_global|Lock|jFrogPipelinesSessionId:' +
        params.jFrogPipelinesSessionId;
    this.suAdapter = new ApiAdapter(params.jFrogPipelinesSessionId, config.apiToken);
}
Lock.prototype.obtain = function (callback) {
    var self = this;
    var who = self.who + '|obtainLock|' + self.name;
    logger.trace(who, 'Inside');
    const systemServiceInstanceId = applicationContext.get(SYSTEM_SERVICE_INSTANCE_INITIALIZER).systemServiceInstancesId;
    var body = {
        name: self.name,
        systemServiceInstanceId: systemServiceInstanceId,
        timeoutAt: new Date(Date.now() + self.timeoutInMs).toISOString()
    };
    self.suAdapter.postLock(body, function (err, lock) {
        if (err) {
            logger.debug(who, util.format('Failed to post lock: %s with error: %s', body.name, err));
            return callback('Failed to obtain lock');
        }
        self.id = lock.id;
        self.isValid = true;
        self.timeoutAt = lock.timeoutAt;
        self.timeout = self.setLockTimer.bind(self)();
        return callback(null);
    });
};
Lock.prototype.setLockTimer = function () {
    var self = this;
    if (!self.isValid)
        return;
    var who = self.who + '|setLockTimer|' + self.name;
    logger.trace(who, 'Inside');
    return setTimeout(self.checkLock.bind(self), self.timerIntervalInMs);
};
Lock.prototype.checkLock = function () {
    var self = this;
    if (!self.isValid)
        return;
    var who = self.who + '|checkLock|' + self.name;
    logger.trace(who, 'Inside');
    var existingLockTimeoutAt = new Date(self.timeoutAt);
    existingLockTimeoutAt.setTime(existingLockTimeoutAt.getTime() +
        self.timeoutInMs);
    var update = {
        timeoutAt: existingLockTimeoutAt.toISOString()
    };
    self.suAdapter.putLockById(self.id, update, function (err) {
        if (err) {
            logger.warn(who, 'Failed to update lock with id:', self.id, ' with error:', err);
            logger.warn(who, 'Invalidated lock with name:', self.name, '& id:', self.id);
            self.isValid = false;
            return;
        }
        self.timeoutAt = update.timeoutAt;
        self.timeout = self.setLockTimer.bind(self)();
    });
};
Lock.prototype.release = function (callback) {
    var self = this;
    var who = self.who + '|releaseLock|' + self.name;
    logger.trace(who, 'Inside');
    self.isValid = false;
    clearTimeout(self.timeout);
    if (!self.id) {
        return callback(null);
    }
    self.suAdapter.deleteLockById(self.id, '', function (err) {
        if (err)
            logger.debug(who, 'Failed to delete lock', self.name, 'with err', err);
        return callback(null);
    });
};
Lock.prototype.destroy = function () {
    if (this.timeout)
        clearTimeout(this.timeout);
    this.setLockTimer = () => { };
    this.checkLock = () => { };
};
//# sourceMappingURL=Lock.js.map