"use strict";
const TROUBLESHOOT_MSG = '\n For more information, see documentation here https://www.jfrog.com/confluence/display/JFROG/Defining+a+Pipeline#DefiningaPipeline-configurationPipelineConfiguration';
const waitingMessageComposerFactory = {
    waitingForFreeNodePoolCapacity: ({ nodePoolName, numberOfNodes }) => ({
        group: 'Waiting for free node pool capacity',
        cmd: `Node pool [${nodePoolName}] capacity is full with capacity: ${numberOfNodes}`,
        message: '\nEither increase the node pool capacity or wait until any one of the nodes becomes free to process this step.'
    }),
    waitingForFreeLicenseCapacity: ({ maxCapacity }) => ({
        group: 'Waiting for free license capacity',
        cmd: `Concurrent build capacity limits are fully occupied with max capacity: ${maxCapacity}`,
        message: '\nEither increase the license limit or wait until the capacity becomes free.'
    }),
    waitingForParentPipelineToComplete: ({ pipelineNames }) => ({
        group: 'Waiting for parent pipeline to complete',
        cmd: `Parent pipeline/s [ ${pipelineNames.join(', ')} ] is in progress`,
        message: `\nThe current step is waiting because the current pipeline depends on other pipelines and will be able to start only once these pipelines complete. 
      \nThis dependency is defined by having dependencyMode: waitOnParentComplete in the current pipeline’s definition. ${TROUBLESHOOT_MSG}`
    }),
    waitingForParentPipelineToSuccess: ({ pipelineNames }) => ({
        group: 'Waiting for parent pipeline to success',
        cmd: `Parent pipeline/s [ ${pipelineNames.join(', ')} ] is in progress`,
        message: `\nThe current step is waiting because the current pipeline depends on other pipelines and will be able to start only once these pipelines complete. 
      \nThis dependency is defined by having dependencyMode: waitOnParentSuccess in the current pipeline’s definition. ${TROUBLESHOOT_MSG}`
    }),
    waitingForChildPipelineToSuccess: ({ pipelineNames }) => ({
        group: 'Waiting for child pipeline to success',
        cmd: `Child pipeline/s [ ${pipelineNames.join(', ')} ] is not success yet`,
        message: `\nThe current step is waiting because the current pipeline depends on other pipelines and will be able to start only once these pipelines complete. 
      \n This dependency is defined by having dependencyMode: waitOnChildSuccess in the current pipeline’s definition. ${TROUBLESHOOT_MSG}`
    }),
    waitingForInputStepsToComplete: ({ inputStepNamesByStepletId }) => {
        const waitingLogs = [];
        _.each(inputStepNamesByStepletId, function (values, stepletId) {
            if (values instanceof Set) {
                const inputStepNames = [...values];
                waitingLogs.push({
                    stepletId: stepletId,
                    group: 'Waiting for input steps to complete',
                    cmd: `Input steps [ ${inputStepNames.join(', ')} ] are still not finished yet`,
                    message: `\nThe current step is waiting because the current step depends on other steps and will be able to start only once these steps complete. 
            \n This dependency is defined by having inputSteps: [] in the current pipeline’s definition. ${TROUBLESHOOT_MSG}`
                });
            }
        });
        return waitingLogs;
    },
    waitingForPreviousRunToFinish: ({ previousRunNumber, pipelineName }) => ({
        group: 'Waiting for previous run to complete',
        cmd: `Previous run #${previousRunNumber} of ${pipelineName} is still in progress`,
        message: `\nThe current step is waiting because the current pipeline depends on other pipelines and will be able to start only the old runs this pipelines complete. 
      \nThis dependency is defined by having chronological: true in the current pipeline’s definition. ${TROUBLESHOOT_MSG}`
    }),
    waitingForChildPipelineToComplete: ({ pipelineNames }) => ({
        group: 'Waiting for child pipeline to complete',
        cmd: `Child pipeline/s [ ${pipelineNames.join(', ')} ] is not complete yet`,
        message: `\nThe current step is waiting because the current pipeline depends on other pipelines and will be able to start only once these pipelines complete. 
      \nThis dependency is defined by having dependencyMode: waitOnChildComplete in the current pipeline’s definition. ${TROUBLESHOOT_MSG}`
    }),
    waitingForApproval: () => ({
        group: 'Waiting for approvals',
        cmd: `Awaiting for approval from required approvers`,
        message: `\nThe current step won't start until the required approvers approve this step.`
    }),
};
const waitingConditions = Object.keys(waitingMessageComposerFactory);
module.exports.EXPERIMENTAL_PROPERTIES_CONFIG_NAME = 'experimentalProperties';
module.exports.waitingConditions = waitingConditions;
module.exports.waitingMessageComposerFactory = waitingMessageComposerFactory;
//# sourceMappingURL=constants.js.map