'use strict';
var self = getDownStreamStepIds;
module.exports = self;
var _ = require('underscore');
var async = require('async');
function getDownStreamStepIds(externalBag, callback) {
    var who = externalBag.who + '|' + getDownStreamStepIds.name;
    logger.debug(who, 'Inside');
    var bag = {
        who: externalBag.who,
        stepId: externalBag.stepId,
        runStepConnectionsByStepId: externalBag.runStepConnectionsByStepId,
        runStepConnectionsByOperationStepId: externalBag.runStepConnectionsByOperationStepId,
        runStepConnectionsByResourceName: externalBag.runStepConnectionsByResourceName,
        runResourceVersionsById: externalBag.runResourceVersionsById,
    };
    var stepId = bag.stepId;
    var downstreamStepIdsSet = new Set();
    var queue = [{
            stepId: stepId
        }];
    var allStepIdsQueuedSet = new Set().add(stepId);
    var allRunResourceVersionNamesQueued = [];
    async.whilst(function () {
        return !_.isEmpty(queue);
    }, function (done) {
        var element = queue.shift();
        if (element.stepId) {
            if (stepId !== element.stepId)
                downstreamStepIdsSet.add(element.stepId);
            var runStepConnectionsForStepByOperationStepId = bag.runStepConnectionsByOperationStepId[element.stepId];
            _.each(runStepConnectionsForStepByOperationStepId, function (connection) {
                if (connection.operation !== 'IN')
                    return;
                if (stepId === connection.stepId)
                    return;
                if (downstreamStepIdsSet.has(connection.stepId))
                    return;
                if (allStepIdsQueuedSet.has(connection.stepId))
                    return;
                queue.push({
                    stepId: connection.stepId
                });
                allStepIdsQueuedSet.add(connection.stepId);
            });
            var runStepConnectionsForStep = bag.runStepConnectionsByStepId[element.stepId];
            _.each(runStepConnectionsForStep, function (connection) {
                if (connection.operation !== 'OUT')
                    return;
                if (!connection.operationRunResourceVersionId)
                    return;
                var runResourceVersion = bag.runResourceVersionsById[connection.operationRunResourceVersionId];
                if (!runResourceVersion)
                    return;
                var resourceNameAndBranch = {
                    runResourceVersionName: connection.operationRunResourceVersionName,
                    pipelineSourceBranch: runResourceVersion.pipelineSourceBranch
                };
                if (_.findWhere(allRunResourceVersionNamesQueued, resourceNameAndBranch))
                    return;
                queue.push(resourceNameAndBranch);
                allRunResourceVersionNamesQueued.push(resourceNameAndBranch);
            });
        }
        else if (element.runResourceVersionName) {
            var resDownstreamINConnections = _.filter(bag.runStepConnectionsByResourceName[element.runResourceVersionName], function (connection) {
                var operationRunResourceVersionId = connection.operationRunResourceVersionId;
                var runResourceVersion = bag.runResourceVersionsById[operationRunResourceVersionId];
                if (!runResourceVersion)
                    return false;
                return connection.operation === 'IN' &&
                    runResourceVersion.pipelineSourceBranch ===
                        element.pipelineSourceBranch;
            });
            _.each(resDownstreamINConnections, function (connection) {
                if (stepId === connection.stepId)
                    return;
                if (downstreamStepIdsSet.has(connection.stepId))
                    return;
                if (allStepIdsQueuedSet.has(connection.stepId))
                    return;
                queue.push({
                    stepId: connection.stepId
                });
                allStepIdsQueuedSet.add(connection.stepId);
            });
        }
        return process.nextTick(done);
    }, function () {
        return callback(Array.from(downstreamStepIdsSet));
    });
}
//# sourceMappingURL=getDownStreamStepIds.js.map