'use strict';
var self = createArtifactoryToken;
module.exports = self;
var async = require('async');
var jfrogAccess = require('@jfrog/access-nodejs-client');
function createArtifactoryToken(params, callback) {
    var bag = {
        jFrogPipelinesSessionId: params.jFrogPipelinesSessionId,
        tokenPermissions: 'applied-permissions/admin api:*',
        accessClient: params.accessClient,
        accessClientContext: params.accessClientContext,
        tokenExpirationIntervalSecs: params.tokenExpirationIntervalSecs || 120
    };
    bag.who = util.format('%s|_global|artifactory|%s|jFrogPipelinesSessionId:%s', params.who, self.name, bag.jFrogPipelinesSessionId);
    logger.debug(bag.who, 'Starting');
    async.series([
        _createArtifactoryToken.bind(null, bag)
    ], function (err) {
        logger.trace(bag.who, 'Completed');
        if (err)
            return callback(err);
        return callback(null, bag.rtAccessToken);
    });
}
function _createArtifactoryToken(bag, next) {
    var who = bag.who + '|' + _createArtifactoryToken.name;
    logger.trace(who, 'Inside');
    var username = global.config.rtServiceId;
    var request = new jfrogAccess.CreateTokenRequestModel(bag.tokenPermissions, false, username, 'jfrt@*', bag.tokenExpirationIntervalSecs);
    bag.accessClient.createToken(bag.accessClientContext, request)
        .then(function (response) {
        bag.rtAccessToken = response.accessToken;
        return next();
    })
        .catch(function (err) {
        logger.warn(bag.who, 'Failed to create access token for Artifactory', err);
        return next(new ActErr(who, ActErr.InternalServer, 'Failed to create access token for Artifactory with error:', err));
    });
}
//# sourceMappingURL=createArtifactoryToken.js.map