'use strict';
const defaultNamespace = 'jfrog';
const JFROG_PIPELINES_DIR = '/opt/jfrog/pipelines';
const defaultPlatformForExtension = {
    os: 'Linux'
};
const DEFAULT_STEP_TIMEOUT_SECONDS = 3600;
const DEFAULT_DISK_SIZE = 60;
const CALL_OBJECT_LIMIT = 100;
const CALL_OBJECT_LIMIT_FOR_BATCH = 300;
const PIPE_INFO_VERSION = '1.0.0';
const MIN_RETRY_INTERVAL_MS = 3 * 1000;
const CUSTOM_CERTS_FILENAME = 'pipelines_custom_certs.crt';
const EXPONENTIAL_RETRY_OPTIONS = {
    times: 10,
    interval: function (retryCount) {
        return (MIN_RETRY_INTERVAL_MS + (1000 * Math.pow(2, retryCount)));
    }
};
const KEEP_ALIVE = {
    TIMEOUT_SEC: 60,
    MAX_CONNECTIONS: 5000
};
const LOGGING = {
    SERVICE_COLOR: 'green',
    DIR: process.env.LOG_DIR || 'logs',
};
const SERVICES_NAME_TO_TYPE_MAP = {
    hookHandler: 'jfphh',
    stepTrigger: 'jfpst',
    runTrigger: 'jfprt',
    reqSealer: 'jfprs',
    extensionSync: 'jfpes',
    logup: 'jfplog',
    pipelineSync: 'jfpps',
    templateSync: 'jfpts',
    marshaller: 'jfpmar',
    nexec: 'jfpnex',
    cron: 'jfpcrn',
    eventHandler: "jfpeh"
};
const TROUBLESHOOT_MSG = 'For more information, see ' +
    'https://www.jfrog.com/confluence/display/JFROG/' +
    'Troubleshooting#Troubleshooting-PipelinesErrorMessages';
const MAX_URL_LENGTH = 4000;
const XRAY_SCAN_STEP = 'XrayScan';
const XRAY_ENABLED_STEPS = [
    'NpmPublish',
    'DockerPush',
    'GoPublishBinary',
    'GoPublishModule',
    'GradleBuild',
    'MvnBuild',
    'PublishBuildInfo',
    XRAY_SCAN_STEP,
];
const WILDCARD_AUDIENCE = '*@*';
const ACTIVITY_EVENT_LOGGER_ID = 'activity-event';
const HELLO_WORLD_TEMPLATE_NAME = 'HelloWorld';
const JFROG_TEMPLATE_NAMESPACE = 'jfrog';
const PRE_RUN_HOOK_STEP_INPUT_STEP_STATUSES = ["success", "failure", "error", "cancelled", "skipped", "timeout"];
module.exports = {
    defaultNamespace,
    DEFAULT_STEP_TIMEOUT_SECONDS,
    JFROG_PIPELINES_DIR,
    defaultPlatformForExtension,
    DEFAULT_DISK_SIZE,
    CALL_OBJECT_LIMIT,
    CALL_OBJECT_LIMIT_FOR_BATCH,
    PIPE_INFO_VERSION,
    SERVICES_NAME_TO_TYPE_MAP,
    EXPONENTIAL_RETRY_OPTIONS,
    MAX_URL_LENGTH,
    XRAY_ENABLED_STEPS,
    XRAY_SCAN_STEP,
    TROUBLESHOOT_MSG,
    LOGGING,
    ACTIVITY_EVENT_LOGGER_ID,
    KEEP_ALIVE,
    CUSTOM_CERTS_FILENAME,
    HELLO_WORLD_TEMPLATE_NAME,
    JFROG_TEMPLATE_NAMESPACE,
    PRE_RUN_HOOK_STEP_INPUT_STEP_STATUSES,
    WILDCARD_AUDIENCE
};
//# sourceMappingURL=constants.js.map