'use strict';
var self = getInputStepsForStep;
module.exports = self;
var async = require('async');
var _ = require('underscore');
function getInputStepsForStep(externalBag, callback) {
    var bag = {
        who: externalBag.who || '',
        suAdapter: externalBag.suAdapter,
        inputSteps: [],
        step: externalBag.step,
        runStepConnections: externalBag.runStepConnections,
        runResourceVersionsById: externalBag.runResourceVersionsById,
        jFrogPipelinesSessionId: externalBag.jFrogPipelinesSessionId,
        res: {},
    };
    bag.who = util.format('%s|%s|jFrogPipelinesSessionId:%s|', bag.who, self.name, bag.jFrogPipelinesSessionId);
    logger.info(bag.who, 'Starting');
    async.series([
        _checkInputParams.bind(null, bag),
        _getInputSteps.bind(null, bag)
    ], function (err) {
        logger.info(bag.who, 'Completed');
        if (err)
            return callback(err, {});
        bag.res = {
            inputStepIds: bag.inputStepIds || [],
        };
        return callback(null, bag.res);
    });
}
function _checkInputParams(bag, next) {
    var who = bag.who + '|' + _checkInputParams.name;
    logger.debug(who, 'Inside');
    if (!bag.suAdapter)
        return next(new ActErr(who, ActErr.DataNotFound, 'not found bag.suAdapter'));
    if (_.isEmpty(bag.step))
        return next(new ActErr(who, ActErr.DataNotFound, 'not found bag.step'));
    if (!_.isArray(bag.runStepConnections))
        return next(new ActErr(who, ActErr.DataNotFound, 'not found bag.runStepConnections'));
    if (_.isUndefined(bag.runResourceVersionsById))
        return next(new ActErr(who, ActErr.DataNotFound, 'not found bag.runResourceVersionsById'));
    return next();
}
function _getInputSteps(bag, next) {
    var who = bag.who + '|' + _getInputSteps.name;
    logger.debug(who, 'Inside');
    var innerBag = {
        who: bag.who,
        step: bag.step,
        runStepConnections: bag.runStepConnections,
        runResourceVersionsById: bag.runResourceVersionsById,
        inStepConnections: [],
        outRunResourceConnections: [],
    };
    async.series([
        __getDirectInConnections.bind(null, innerBag),
        __getIndirectInConnections.bind(null, innerBag)
    ], function () {
        var inStepIds = [];
        var directINStepIds = _.compact(_.uniq(_.pluck(innerBag.inStepConnections, 'operationStepId')));
        var indirectINStepIds = _.uniq(_.pluck(innerBag.outRunResourceConnections, 'stepId'));
        if (!_.isEmpty(directINStepIds))
            inStepIds = inStepIds.concat(directINStepIds);
        if (!_.isEmpty(indirectINStepIds))
            inStepIds = inStepIds.concat(indirectINStepIds);
        bag.inputStepIds = _.uniq(inStepIds);
        return next();
    });
}
function __getDirectInConnections(bag, next) {
    var who = bag.who + '|' + __getDirectInConnections.name;
    logger.debug(who, 'Inside');
    bag.inStepConnections = _.filter(bag.runStepConnections, function (connection) {
        return connection.stepId === bag.step.id &&
            connection.operationStepId && connection.operation === 'IN';
    });
    bag.inRunResourceConnections = _.filter(bag.runStepConnections, function (connection) {
        return connection.stepId === bag.step.id &&
            connection.operation === 'IN' &&
            connection.operationRunResourceVersionId;
    });
    return next();
}
function __getIndirectInConnections(bag, next) {
    var who = bag.who + '|' + __getIndirectInConnections.name;
    logger.debug(who, 'Inside');
    var inputResourceNamesAndBranches = _.uniq(_.compact(_.map(bag.inRunResourceConnections, function (connection) {
        var runResourceVersion = bag.runResourceVersionsById[connection.operationRunResourceVersionId];
        if (!runResourceVersion)
            return null;
        return {
            resourceName: connection.operationRunResourceVersionName,
            pipelineSourceBranch: runResourceVersion.pipelineSourceBranch
        };
    })));
    if (_.isEmpty(inputResourceNamesAndBranches))
        return next();
    var inputResourceAndBranchMap = _.indexBy(inputResourceNamesAndBranches, function (item) {
        return item.resourceName + '___' + item.pipelineSourceBranch;
    });
    bag.outRunResourceConnections = _.filter(bag.runStepConnections, function (connection) {
        if (connection.operation !== 'OUT')
            return false;
        if (!connection.operationRunResourceVersionId)
            return false;
        var runResourceVersion = bag.runResourceVersionsById[connection.operationRunResourceVersionId];
        if (!runResourceVersion)
            return false;
        var key = connection.operationRunResourceVersionName + '___' +
            runResourceVersion.pipelineSourceBranch;
        return !_.isEmpty(inputResourceAndBranchMap[key]);
    });
    return next();
}
//# sourceMappingURL=getInputStepsForStep.js.map