"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AffinityGroupManager = void 0;
const logger_1 = require("@jfrog-pipelines/logger");
const utility_1 = require("@jfrog-pipelines/utility");
const RunAdjacency_1 = require("./RunAdjacency");
const Step_1 = require("./Step");
const Steplet_1 = require("./Steplet");
const WaitingGroup_1 = require("./WaitingGroup");
class AffinityGroupManager {
    constructor(dataAdapter) {
        this.logger = logger_1.LoggerFactory.getLogger('AffinityGroupManager');
        this.runAdjacency = new RunAdjacency_1.RunAdjacency(dataAdapter);
        this.step = new Step_1.Step(dataAdapter);
        this.steplet = new Steplet_1.Steplet(dataAdapter);
    }
    async getAffinityGroups() {
        this.logger.debug('Started getAffinityGroups');
        await this.runAdjacency.populate();
        await Promise.all([this.step.populate(this.runAdjacency), this.steplet.populate(this.runAdjacency)]);
        const waitingGroups = [];
        const runIds = this.runAdjacency.getRunAdjacencyRunIds();
        if (runIds.length === 0) {
            return waitingGroups;
        }
        this.logger.debug('Triggerable runIds length', runIds.length);
        for (const runId of runIds) {
            const groups = this.createAffinityGroupsForRun(Number.parseInt(runId, 10));
            this.logger.trace(`Waiting groups for runId: ${runId}`, groups.length);
            waitingGroups.push(...groups);
        }
        this.logger.info(`Computed waitingGroups: ${waitingGroups.length}`);
        return (0, utility_1.sortBy)(waitingGroups, 'triggeredAt');
    }
    createAffinityGroupsForRun(runId) {
        const waitingGroups = [];
        const { affinityGroups, listByAffinityGroup } = this.runAdjacency.getAffinityGroups(runId);
        for (const affinityGroup of affinityGroups) {
            const waitingGroup = this.mapRunAffinityGroup(runId, affinityGroup, listByAffinityGroup[affinityGroup]);
            if (waitingGroup !== null) {
                waitingGroups.push(waitingGroup);
            }
        }
        return waitingGroups;
    }
    mapRunAffinityGroup(runId, affinityGroup, runAdjacencies) {
        try {
            const waitingGroup = new WaitingGroup_1.WaitingGroup(runId, affinityGroup, this.step, this.steplet, runAdjacencies);
            return waitingGroup;
        }
        catch (error) {
            this.logger.error(error);
            return null;
        }
    }
}
exports.AffinityGroupManager = AffinityGroupManager;
//# sourceMappingURL=AffinityGroupManager.js.map