"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WaitingGroup = void 0;
const utility_1 = require("@jfrog-pipelines/utility");
const logger_1 = require("@jfrog-pipelines/logger");
class WaitingGroup {
    constructor(runId, affinityGroup, step, steplet, runAdjacencies) {
        this.runId = runId;
        this.affinityGroup = affinityGroup;
        this.groupStepIds = [];
        this.rejectionContext = {};
        this.runId = runId;
        this.affinityGroup = affinityGroup;
        this.setRunAdjacencies(runAdjacencies);
        this.setSteplets(runAdjacencies, steplet);
        this.setStepIds(runAdjacencies, step, steplet);
    }
    getStepsToExecute() {
        const sortedStepIdsList = this.getSortedStepIdsForWaitingGroup();
        const groupStepObjectByStepId = (0, utility_1.keyBy)(this.groupStepIds, 'stepId');
        const groupStepIds = [];
        for (const { stepId, sequence } of sortedStepIdsList) {
            groupStepIds.push({ ...groupStepObjectByStepId[stepId], sequence });
        }
        const sequenceGroupedSteps = (0, utility_1.groupBy)(groupStepIds, 'sequence');
        const orderedSteps = (0, utility_1.map)(sequenceGroupedSteps, (sequenceSteps) => {
            return (0, utility_1.sortBy)(sequenceSteps, 'priority');
        });
        const stepsToExecute = (0, utility_1.flatten)(orderedSteps);
        return stepsToExecute.map((step) => {
            return {
                stepId: step.stepId,
                stepletIds: step.stepletIds,
                priority: step.priority,
                sequence: step.sequence
            };
        });
    }
    getApprovalGatesStepIds() {
        const stepIds = [];
        for (const groupStep of this.groupStepIds) {
            if (groupStep.requiresApproval) {
                stepIds.push(groupStep.stepId);
            }
        }
        return stepIds;
    }
    setRunAdjacencies(runAdjacencies) {
        this.runAdjacencyList = runAdjacencies;
        this.requiresApproval = this.hasRequiresApproval(runAdjacencies);
    }
    setSteplets(runAdjacencies, stepletRunAdjacency) {
        const steplets = this.getStepletsFromRunAdjacency(stepletRunAdjacency, runAdjacencies);
        if (steplets.length === 0) {
            throw new Error('steplets are empty!');
        }
        const steplet = steplets[0];
        this.setMeta(steplet);
        this.setIsExternal(steplets);
        this.setPrioerity(steplets);
        this.setTriggeredAt(steplets);
    }
    setMeta(steplet) {
        this.projectId = steplet.projectId;
        this.pipelineId = steplet.pipelineId;
        this.pipelineSourceId = steplet.pipelineSourceId;
        this.nodePoolName = steplet.configPropertyBag.nodePool;
    }
    setTriggeredAt(steplets) {
        this.triggeredAt = new Date(Math.min(...(0, utility_1.map)(steplets, (steplet) => new Date(steplet.triggeredAt).getTime())));
    }
    setPrioerity(steplets) {
        this.priority = Math.min(...(0, utility_1.map)(steplets, 'priority'));
    }
    setIsExternal(steplets) {
        this.isExternal = steplets.some((steplet) => steplet.configPropertyBag.isExternal === true);
    }
    setStepIds(runAdjacencies, stepRunAdjacency, stepletRunAdjacency) {
        const listByAffinityGroupByRunIdByStepIds = (0, utility_1.groupBy)(runAdjacencies, 'stepId');
        const stepIds = (0, utility_1.keys)(listByAffinityGroupByRunIdByStepIds);
        const step = stepRunAdjacency.getStepById(stepIds[0]);
        if ((0, utility_1.isEmpty)(step)) {
            throw new Error(`Step not found with id: ${stepIds[0]}`);
        }
        this.stepIds = (0, utility_1.map)(stepIds, (stepId) => Number.parseInt(stepId, 10));
        this.groupStartedAt = step.groupStartedAt;
        this.firstStepsList = stepIds.filter((stepId) => {
            return listByAffinityGroupByRunIdByStepIds[stepId].length === 1;
        });
        this.setGroupStepIds(stepIds, stepRunAdjacency, stepletRunAdjacency, listByAffinityGroupByRunIdByStepIds);
    }
    getStepletsFromRunAdjacency(stepletRunAdjacency, runAdjacencies) {
        const listByAffinityGroupByRunIdByStepletId = (0, utility_1.groupBy)(runAdjacencies, 'stepletId');
        const stepletIds = (0, utility_1.keys)(listByAffinityGroupByRunIdByStepletId);
        const steplets = (0, utility_1.compact)(stepletIds.map((stepletId) => stepletRunAdjacency.getStepletById(stepletId)));
        return steplets;
    }
    setGroupStepIds(stepIds, stepRunAdjacency, stepletRunAdjacency, runAdjacenciesByStepId) {
        this.groupStepIds = stepIds.map((stepId) => {
            const step = stepRunAdjacency.getStepById(stepId);
            const steplets = this.getStepletsByAffinityGroupAndStepId(stepletRunAdjacency, Number.parseInt(stepId, 10), this.affinityGroup);
            const priority = Math.min(...(0, utility_1.map)(steplets, 'priority'));
            const triggeredAt = new Date(Math.min(...(0, utility_1.map)(steplets, (steplet) => new Date(steplet.triggeredAt).getTime())));
            return {
                runAdjacencyList: runAdjacenciesByStepId[stepId],
                requiresApproval: this.shouldRequestApproval(runAdjacenciesByStepId[stepId], Number.parseInt(stepId, 10)),
                stepId: Number.parseInt(stepId, 10),
                triggeredAt: triggeredAt,
                priority: priority,
                readyAt: step.readyAt,
                stepletIds: (0, utility_1.map)(steplets, 'id'),
                sequence: -1
            };
        });
    }
    getStepletsByAffinityGroupAndStepId(stepletRunAdjacency, stepId, affinityGroup) {
        return stepletRunAdjacency.getStepletsByStepId(stepId).filter((steplet) => steplet.affinityGroup === affinityGroup);
    }
    hasRequiresApproval(runAdjacenciesList) {
        return runAdjacenciesList.some((runAdj) => [6, 7].includes(runAdj.dependentEntityType));
    }
    shouldRequestApproval(runAdjacenciesList, stepId) {
        return runAdjacenciesList.some((runAdj) => runAdj.dependentEntityType === 6 && runAdj.dependentEntityId === stepId);
    }
    getSortedStepIdsForWaitingGroup() {
        const logger = logger_1.LoggerFactory.getLogger(`WaitingGroup:runId:${this.runId}::affinityGroup::${this.affinityGroup}`);
        const list = [...this.runAdjacencyList];
        const sortedStepIdsList = [];
        let sequence = 0;
        const stepIdsSet = new Set(this.stepIds);
        while (list.length > 0) {
            const currentListLength = list.length;
            const stepIdsHavingZeroDeps = this.getStepIdsHavingZeroDeps(stepIdsSet, list, sequence);
            sortedStepIdsList.push(...stepIdsHavingZeroDeps);
            sequence += 1;
            if (currentListLength === list.length) {
                logger.warn('Cyclic loop found. Skipping');
                break;
            }
        }
        return sortedStepIdsList;
    }
    getStepIdsHavingZeroDeps(stepIdsSet, list, sequence) {
        const stepIdsHavingZeroDeps = [];
        const stepIds = [];
        for (const stepId of stepIdsSet) {
            const count = this.getCountForStepId(stepId, list);
            if (count == 0) {
                stepIdsHavingZeroDeps.push({
                    stepId: stepId,
                    sequence: sequence
                });
                stepIds.push(stepId);
            }
        }
        for (const stepId of stepIds) {
            this.removeRunAdjacencies(stepId, list);
            stepIdsSet.delete(stepId);
        }
        return stepIdsHavingZeroDeps;
    }
    getCountForStepId(stepId, list) {
        let count = 0;
        for (const runAdj of list) {
            if (runAdj.dependentEntityType === 0 && runAdj.stepId === stepId) {
                count += 1;
            }
        }
        return count;
    }
    removeRunAdjacencies(stepId, list) {
        const temprorayList = [...list];
        for (const runAdj of temprorayList) {
            if (this.hasStepRunAdjacency(runAdj, stepId)) {
                const index = list.findIndex((item) => item.id === runAdj.id);
                if (index > -1) {
                    list.splice(index, 1);
                }
            }
        }
    }
    hasStepRunAdjacency(runAdjacency, stepId) {
        return (runAdjacency.stepId === stepId ||
            (runAdjacency.dependentEntityId === stepId && runAdjacency.dependentEntityType === 0));
    }
}
exports.WaitingGroup = WaitingGroup;
//# sourceMappingURL=WaitingGroup.js.map