"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const dataAdapter_1 = require("../../dataAdapter");
const AffinityGroupManager_1 = require("../AffinityGroupManager");
jest.mock('@jfrog-pipelines/logger', () => {
    return {
        ...jest.requireActual('@jfrog-pipelines/logger'),
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                info: jest.fn(),
                error: jest.fn(),
                debug: jest.fn(),
                trace: jest.fn(),
                warn: jest.fn()
            }),
            configure: jest.fn()
        }
    };
});
describe('AffinityGroupFactory test cases', () => {
    it('should get affinityGroups when empty list', async () => {
        jest.spyOn(dataAdapter_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([]);
        jest.spyOn(dataAdapter_1.ApiDataAdapter.prototype, 'getStepletsByStepletIds').mockResolvedValue([]);
        jest.spyOn(dataAdapter_1.ApiDataAdapter.prototype, 'getSteps').mockResolvedValue([]);
        const affinityGroupManager = new AffinityGroupManager_1.AffinityGroupManager(new dataAdapter_1.ApiDataAdapter({}));
        const waitingGroups = await affinityGroupManager.getAffinityGroups();
        expect(waitingGroups).toHaveLength(0);
    });
    it('should get affinityGroups when has list', async () => {
        jest.spyOn(dataAdapter_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            }
        ]);
        jest.spyOn(dataAdapter_1.ApiDataAdapter.prototype, 'getStepletsByStepletIds').mockResolvedValue([
            {
                id: 2923,
                stepId: 2912,
                affinityGroup: 'group',
                configPropertyBag: {}
            }
        ]);
        jest.spyOn(dataAdapter_1.ApiDataAdapter.prototype, 'getSteps').mockResolvedValue([
            {
                id: 2912,
                runId: 1029,
                affinityGroup: 'group',
                groupStartedAt: new Date()
            }
        ]);
        const affinityGroupManager = new AffinityGroupManager_1.AffinityGroupManager(new dataAdapter_1.ApiDataAdapter({}));
        const waitingGroups = await affinityGroupManager.getAffinityGroups();
        expect(waitingGroups).toHaveLength(1);
    });
});
//# sourceMappingURL=AffinityGroupManager.test.js.map