"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const RunAdjacency_1 = require("../RunAdjacency");
const ApiDataAdapter_1 = require("../../dataAdapter/ApiDataAdapter");
describe('RunAdjacency test cases', () => {
    it('should populate when empty triggereableSteps', async () => {
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([]);
        const runAdjacency = new RunAdjacency_1.RunAdjacency(new ApiDataAdapter_1.ApiDataAdapter({}));
        await runAdjacency.populate();
        expect(runAdjacency.getRunAdjacencyByRunId).toBeDefined();
    });
    it('should populate when there are triggerable steps', async () => {
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            },
            {
                id: 614,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: 0,
                dependentEntityId: 2910
            },
            {
                id: 609,
                runId: 1029,
                stepId: 2910,
                stepletId: 2921,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            }
        ]);
        const runAdjacency = new RunAdjacency_1.RunAdjacency(new ApiDataAdapter_1.ApiDataAdapter({}));
        await runAdjacency.populate();
        expect(runAdjacency.getRunAdjacencyByRunId).toBeDefined();
    });
    it('should populate when there are triggerable steps and waitOnParentComplete pipelines', async () => {
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            },
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: 3,
                dependentEntityId: 1
            },
            {
                id: 614,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: 0,
                dependentEntityId: 2910
            },
            {
                id: 609,
                runId: 1029,
                stepId: 2910,
                stepletId: 2921,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            }
        ]);
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getRuns').mockResolvedValue([{ id: 1, pipelineId: 1 }]);
        const runAdjacency = new RunAdjacency_1.RunAdjacency(new ApiDataAdapter_1.ApiDataAdapter({}));
        await runAdjacency.populate();
        expect(runAdjacency.getRunAdjacencyRunIds()).toStrictEqual([]);
    });
    it('should populate when there are triggerable steps and waitOnChildComplete pipelines', async () => {
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            },
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: 5,
                dependentEntityId: 1
            },
            {
                id: 614,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: 0,
                dependentEntityId: 2910
            },
            {
                id: 609,
                runId: 1029,
                stepId: 2910,
                stepletId: 2921,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            }
        ]);
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getRuns').mockResolvedValue([{ id: 1, pipelineId: 1 }]);
        const runAdjacency = new RunAdjacency_1.RunAdjacency(new ApiDataAdapter_1.ApiDataAdapter({}));
        await runAdjacency.populate();
        expect(runAdjacency.getRunAdjacencyRunIds()).toStrictEqual([]);
    });
    it('should populate when there are triggerable steps and waitOnParentSuccess pipelines', async () => {
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            },
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: 4,
                dependentEntityId: 1
            },
            {
                id: 614,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: 0,
                dependentEntityId: 2910
            },
            {
                id: 609,
                runId: 1029,
                stepId: 2910,
                stepletId: 2921,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            }
        ]);
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getRuns').mockResolvedValue([{ id: 1, pipelineId: 1 }]);
        const runAdjacency = new RunAdjacency_1.RunAdjacency(new ApiDataAdapter_1.ApiDataAdapter({}));
        await runAdjacency.populate();
        expect(runAdjacency.getRunAdjacencyRunIds()).toStrictEqual([]);
    });
    it('should populate when there are triggerable steps and waitOnParentSuccess pipelines with unsuccesfull parent', async () => {
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            },
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: 4,
                dependentEntityId: 1
            },
            {
                id: 614,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: 0,
                dependentEntityId: 2910
            },
            {
                id: 609,
                runId: 1029,
                stepId: 2910,
                stepletId: 2921,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            }
        ]);
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getRuns').mockResolvedValue([]);
        jest
            .spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getPipelines')
            .mockResolvedValue([{ id: 1, latestCompletedRunId: 10, latestSuccessfulRunId: 11 }]);
        const runAdjacency = new RunAdjacency_1.RunAdjacency(new ApiDataAdapter_1.ApiDataAdapter({}));
        await runAdjacency.populate();
        expect(runAdjacency.getRunAdjacencyRunIds()).toStrictEqual([]);
    });
});
//# sourceMappingURL=RunAdjacency.test.js.map