"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utility_1 = require("@jfrog-pipelines/utility");
const dataAdapter_1 = require("../../dataAdapter");
const Step_1 = require("../Step");
const Steplet_1 = require("../Steplet");
const WaitingGroup_1 = require("../WaitingGroup");
describe('Waiting group test cases', () => {
    const steps = [
        {
            id: 2910,
            runId: 1029,
            affinityGroup: 'group'
        },
        {
            id: 2912,
            runId: 1029,
            affinityGroup: 'group'
        },
        {
            id: 2913,
            runId: 1029,
            affinityGroup: 'group'
        },
        {
            id: 2919,
            runId: 1029,
            affinityGroup: 'group'
        }
    ];
    const stepsById = (0, utility_1.keyBy)(steps, 'id');
    const steplets = [
        {
            id: 2921,
            stepId: 2910,
            runId: 1029,
            affinityGroup: 'group',
            priority: 1,
            configPropertyBag: {
                nodePool: 'default'
            }
        },
        {
            id: 2919,
            stepId: 2919,
            runId: 1029,
            affinityGroup: 'group',
            priority: 1,
            configPropertyBag: {
                nodePool: 'default'
            }
        },
        {
            id: 2923,
            stepId: 2912,
            runId: 1029,
            priority: 3,
            affinityGroup: 'group',
            configPropertyBag: {
                nodePool: 'default'
            }
        },
        {
            id: 2924,
            stepId: 2913,
            runId: 1029,
            priority: 2,
            affinityGroup: 'group',
            configPropertyBag: {
                nodePool: 'default'
            }
        }
    ];
    const stepletByStepId = (0, utility_1.groupBy)(steplets, 'stepId');
    const stepletsById = (0, utility_1.keyBy)(steplets, 'id');
    const waitingGroupTestData = {
        groupStepIds: [
            {
                runAdjacencyList: [
                    {
                        id: 609,
                        runId: 1029,
                        stepId: 2910,
                        stepletId: 2921,
                        affinityGroup: 'group',
                        dependentEntityType: -1,
                        dependentEntityId: -1
                    }
                ],
                requiresApproval: false,
                stepId: 2910,
                triggeredAt: '2023-03-29T06:06:41.170Z',
                priority: 1,
                readyAt: '2023-03-29T06:07:03.825Z',
                stepletIds: [2921],
                sequence: -1
            },
            {
                runAdjacencyList: [
                    {
                        id: 613,
                        runId: 1029,
                        stepId: 2912,
                        stepletId: 2923,
                        affinityGroup: 'group',
                        dependentEntityType: -1,
                        dependentEntityId: -1
                    },
                    {
                        id: 614,
                        runId: 1029,
                        stepId: 2912,
                        stepletId: 2923,
                        affinityGroup: 'group',
                        dependentEntityType: 0,
                        dependentEntityId: 2910
                    }
                ],
                requiresApproval: false,
                stepId: 2912,
                triggeredAt: '2023-03-29T06:06:41.170Z',
                priority: 3,
                readyAt: null,
                stepletIds: [2923],
                sequence: -1
            },
            {
                runAdjacencyList: [
                    {
                        id: 614,
                        runId: 1029,
                        stepId: 2913,
                        stepletId: 2924,
                        affinityGroup: 'group',
                        dependentEntityType: -1,
                        dependentEntityId: -1
                    },
                    {
                        id: 615,
                        runId: 1029,
                        stepId: 2913,
                        stepletId: 2924,
                        affinityGroup: 'group',
                        dependentEntityType: 0,
                        dependentEntityId: 2910
                    }
                ],
                requiresApproval: false,
                stepId: 2912,
                triggeredAt: '2023-03-29T06:06:41.170Z',
                priority: 2,
                readyAt: null,
                stepletIds: [2923],
                sequence: -1
            }
        ],
        rejectionContext: {},
        affinityGroup: 'group',
        priority: 1,
        triggeredAt: '2023-03-29T06:06:41.170Z',
        projectId: 1,
        pipelineId: 246,
        pipelineSourceId: 179,
        runId: 1029,
        groupStartedAt: '2023-03-29T06:07:06.033Z',
        runAdjacencyList: [
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            },
            {
                id: 614,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: 0,
                dependentEntityId: 2910
            },
            {
                id: 609,
                runId: 1029,
                stepId: 2910,
                stepletId: 2921,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            },
            {
                id: 609,
                runId: 1029,
                stepId: 2910,
                stepletId: 2921,
                affinityGroup: 'group',
                dependentEntityType: 6,
                dependentEntityId: 2910
            },
            {
                id: 614,
                runId: 1029,
                stepId: 2913,
                stepletId: 2924,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            },
            {
                id: 615,
                runId: 1029,
                stepId: 2913,
                stepletId: 2924,
                affinityGroup: 'group',
                dependentEntityType: 0,
                dependentEntityId: 2910
            },
            {
                id: 615,
                runId: 1029,
                stepId: 2919,
                stepletId: 2924,
                affinityGroup: 'group',
                dependentEntityType: 0,
                dependentEntityId: 2919
            }
        ],
        firstStepsList: ['2910'],
        stepIds: [2910, 2912, 2913],
        nodePoolName: 'pool'
    };
    const dataAdapter = new dataAdapter_1.ApiDataAdapter({});
    const step = new Step_1.Step(dataAdapter);
    jest.spyOn(step, 'getStepById').mockImplementation((stepId) => {
        return stepsById[stepId];
    });
    const steplet = new Steplet_1.Steplet(dataAdapter);
    jest.spyOn(steplet, 'getStepletsByStepId').mockImplementation((stepId) => {
        return stepletByStepId[stepId];
    });
    jest.spyOn(steplet, 'getStepletById').mockImplementation((stepletId) => {
        return stepletsById[stepletId];
    });
    const waitingGroup = new WaitingGroup_1.WaitingGroup(1029, 'group', step, steplet, waitingGroupTestData.runAdjacencyList);
    test('should sort the steps by dependency', () => {
        const sortedSteps = waitingGroup.getStepsToExecute();
        expect(sortedSteps).toStrictEqual([
            { stepId: 2910, stepletIds: [2921], priority: 1, sequence: 0 },
            { stepId: 2913, stepletIds: [2924], priority: 2, sequence: 1 },
            { stepId: 2912, stepletIds: [2923], priority: 3, sequence: 1 }
        ]);
    });
    test('should getApprovalGatesStepIds', () => {
        expect(waitingGroup.getApprovalGatesStepIds()).toStrictEqual([2910]);
    });
});
//# sourceMappingURL=WaitingGroup.test.js.map