"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApiDataAdapter = void 0;
const utility_1 = require("@jfrog-pipelines/utility");
const constants_1 = require("../constants");
class ApiDataAdapter {
    constructor(pipelinesClient) {
        this.pipelinesClient = pipelinesClient;
    }
    async getTriggerableSteps() {
        const runAdjacencyList = [];
        let currentLimit = constants_1.CALL_OBJECT_LIMIT_FOR_BATCH;
        let currentSkip = 0;
        let triggerableSteps = [];
        do {
            triggerableSteps = await this.pipelinesClient.getTriggerableSteps(currentLimit, currentSkip);
            runAdjacencyList.push(...triggerableSteps);
            currentLimit += constants_1.CALL_OBJECT_LIMIT_FOR_BATCH;
            currentSkip += constants_1.CALL_OBJECT_LIMIT_FOR_BATCH;
        } while (triggerableSteps.length === constants_1.CALL_OBJECT_LIMIT_FOR_BATCH);
        return runAdjacencyList;
    }
    async deleteRunAdjacencyByIds(runAdjacencyIds) {
        if (runAdjacencyIds.length === 0) {
            return 0;
        }
        const query = {
            runAdjacencyIds: runAdjacencyIds.join(',')
        };
        return this.pipelinesClient.deleteRunAdjacencies(query);
    }
    getRunAdjacencyByQuery(query) {
        return this.pipelinesClient.getRunAdjacenies(query);
    }
    async getSteps(stepIds, query) {
        if (stepIds.length === 0) {
            return [];
        }
        const chunks = (0, utility_1.chunk)(stepIds, constants_1.CALL_OBJECT_LIMIT);
        const getStepsPromises = chunks.map(async (stepIds) => {
            return this.pipelinesClient.getSteps(`stepIds=${stepIds.join(',')}&${query}`);
        });
        const steps = (0, utility_1.flatten)(await Promise.all(getStepsPromises));
        return steps;
    }
    async getStepletsByStepletIds(stepletIds, query) {
        if (stepletIds.length === 0) {
            return [];
        }
        const chunks = (0, utility_1.chunk)(stepletIds, constants_1.CALL_OBJECT_LIMIT);
        const getStepletsPromises = chunks.map(async (stepletIds) => {
            return this.pipelinesClient.getSteplets(`stepletIds=${stepletIds.join(',')}&${query}`);
        });
        const steplets = (0, utility_1.flatten)(await Promise.all(getStepletsPromises));
        return steplets;
    }
    async getRuns(pipelineIds, query) {
        if (pipelineIds.length === 0) {
            return [];
        }
        const chunks = (0, utility_1.chunk)(pipelineIds, constants_1.CALL_OBJECT_LIMIT);
        const getRunsPromises = chunks.map(async (pipelineIds) => {
            return this.pipelinesClient.getRuns(`pipelineIds=${pipelineIds.join(',')}&${query}`);
        });
        const runs = (0, utility_1.flatten)(await Promise.all(getRunsPromises));
        return runs;
    }
    async getPipelines(pipelineIds, query) {
        if (pipelineIds.length === 0) {
            return [];
        }
        const chunks = (0, utility_1.chunk)(pipelineIds, constants_1.CALL_OBJECT_LIMIT);
        const getPipelinesPromises = chunks.map(async (pipelineIds) => {
            return this.pipelinesClient.getPipelines(`pipelineIds=${pipelineIds.join(',')}&${query}`);
        });
        const pipelines = (0, utility_1.flatten)(await Promise.all(getPipelinesPromises));
        return pipelines;
    }
    updateStepsReadyAt(stepIds) {
        return this.pipelinesClient.updateSteps({
            query: {
                stepIds: stepIds
            },
            update: {
                readyAt: new Date()
            }
        });
    }
    async getStepsWaitingForApprovalRequest(stepIds) {
        if (stepIds.length === 0) {
            return [];
        }
        const chunks = (0, utility_1.chunk)(stepIds, constants_1.CALL_OBJECT_LIMIT);
        const getWaitingSteps = chunks.map(async (stepIds) => {
            const query = `dependentEntityIds=${stepIds.join(',')}&dependentEntityTypes=${6}`;
            return this.getRunAdjacencyByQuery(query);
        });
        const runAdjacencyRecords = (0, utility_1.flatten)(await Promise.all(getWaitingSteps));
        const approvalRequestStepIds = (0, utility_1.map)(runAdjacencyRecords, 'dependentEntityId');
        return approvalRequestStepIds.map((stepId) => {
            return {
                id: stepId
            };
        });
    }
}
exports.ApiDataAdapter = ApiDataAdapter;
//# sourceMappingURL=ApiDataAdapter.js.map