"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const internal_clients_1 = require("@jfrog-pipelines/internal-clients");
const ApiDataAdapter_1 = require("../ApiDataAdapter");
jest.mock('@jfrog-pipelines/configuration', () => ({
    ConfigFactory: {
        config: {
            apiUrl: 'http://example.com',
            controlPlaneVersion: '1.23.6'
        }
    }
}));
describe('ApiDataAdapter test cases', () => {
    const apiDataAdapter = new ApiDataAdapter_1.ApiDataAdapter(new internal_clients_1.PipelinesClient(4, 'token'));
    it('should be defined', () => {
        expect(apiDataAdapter).toBeDefined();
    });
    it('should get triggerableSteps', async () => {
        const getTriggerableStepsSpy = jest
            .spyOn(internal_clients_1.PipelinesClient.prototype, 'getTriggerableSteps')
            .mockResolvedValue([{ id: 1 }]);
        const actual = await apiDataAdapter.getTriggerableSteps();
        expect(getTriggerableStepsSpy).toHaveBeenCalledTimes(1);
        expect(actual).toStrictEqual([
            {
                id: 1
            }
        ]);
    });
    it('should deleteRunAdjacencyByIds', async () => {
        const spy = jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'deleteRunAdjacencies').mockResolvedValue(1);
        const actual = await apiDataAdapter.deleteRunAdjacencyByIds([1]);
        expect(spy).toHaveBeenCalledTimes(1);
        expect(actual).toStrictEqual(1);
    });
    it('should getRunAdjacency by query', async () => {
        const spy = jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'getRunAdjacenies').mockResolvedValueOnce([]);
        const actual = await apiDataAdapter.getRunAdjacencyByQuery('');
        expect(spy).toHaveBeenCalledTimes(1);
        expect(actual).toStrictEqual([]);
    });
    it('should get steps', async () => {
        const spy = jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'getSteps').mockResolvedValue([]);
        const actual = await apiDataAdapter.getSteps([1], '');
        expect(spy).toHaveBeenCalledTimes(1);
        expect(actual).toStrictEqual([]);
    });
    it('should get steps when empty stepIds', async () => {
        const spy = jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'getSteps').mockResolvedValue([]);
        const actual = await apiDataAdapter.getSteps([], '');
        expect(spy).toHaveBeenCalledTimes(0);
        expect(actual).toStrictEqual([]);
    });
    it('should get stepletsByStepIds', async () => {
        const spy = jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'getSteplets').mockResolvedValue([]);
        const actual = await apiDataAdapter.getStepletsByStepletIds([1], '');
        expect(spy).toHaveBeenCalledTimes(1);
        expect(actual).toStrictEqual([]);
    });
    it('should get stepletsByStepIds when empty', async () => {
        const spy = jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'getSteplets').mockResolvedValue([]);
        const actual = await apiDataAdapter.getStepletsByStepletIds([], '');
        expect(spy).toHaveBeenCalledTimes(0);
        expect(actual).toStrictEqual([]);
    });
    it('should get runs', async () => {
        const spy = jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'getRuns').mockResolvedValue([]);
        const actual = await apiDataAdapter.getRuns([1], '');
        expect(spy).toHaveBeenCalledTimes(1);
        expect(actual).toStrictEqual([]);
    });
    it('should get runs when empty', async () => {
        const spy = jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'getRuns').mockResolvedValue([]);
        const actual = await apiDataAdapter.getRuns([], '');
        expect(spy).toHaveBeenCalledTimes(0);
        expect(actual).toStrictEqual([]);
    });
    it('should get pipelines', async () => {
        const spy = jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'getPipelines').mockResolvedValue([]);
        const actual = await apiDataAdapter.getPipelines([1], '');
        expect(spy).toHaveBeenCalledTimes(1);
        expect(actual).toStrictEqual([]);
    });
    it('should get pipelines when empty', async () => {
        const spy = jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'getPipelines').mockResolvedValue([]);
        const actual = await apiDataAdapter.getPipelines([], '');
        expect(spy).toHaveBeenCalledTimes(0);
        expect(actual).toStrictEqual([]);
    });
    it('should update stepsReadyAt', async () => {
        const spy = jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'updateSteps').mockResolvedValue(1);
        const actual = await apiDataAdapter.updateStepsReadyAt([1]);
        expect(spy).toHaveBeenCalledTimes(1);
        expect(actual).toStrictEqual(1);
    });
    it('should get steps waiting for approval requests', async () => {
        const spy = jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'getRunAdjacenies').mockResolvedValueOnce([
            {
                id: 1,
                dependentEntityId: 1,
                dependentEntityType: 6
            }
        ]);
        const actual = await apiDataAdapter.getStepsWaitingForApprovalRequest(['1', '2']);
        expect(spy).toHaveBeenCalledTimes(1);
        expect(actual).toStrictEqual([
            {
                id: 1
            }
        ]);
    });
});
//# sourceMappingURL=ApiDataAdapter.test.js.map